@@ -1,23 +1,7 @@
-/*
-* Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     liuyanga <liuyanga@uniontech.com>
-*
-* Maintainer: liuyanga <liuyanga@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "middleview.h"
 #include "vnoteapplication.h"
@@ -65,6 +49,7 @@ MiddleView::MiddleView(QWidget *parent)
     //启用多选
     this->setSelectionMode(QAbstractItemView::MultiSelection);
     this->installEventFilter(this);
+    this->setResizeMode(ResizeMode::Adjust);
 }
 
 /**
@@ -299,7 +284,7 @@ void MiddleView::saveAs(SaveAsType type)
     dialog.setDirectory(historyDir);
     //多选或者语音时，选择文件夹
     if (indexList.size() > 1 || type == Voice) {
-        dialog.setFileMode(DFileDialog::DirectoryOnly);
+        dialog.setFileMode(DFileDialog::Directory);
         dialog.setLabelText(DFileDialog::Accept, DApplication::translate("MiddleView", "Save"));
         if (QDialog::Rejected == dialog.exec()) {
             return;
