@@ -1,23 +1,7 @@
-/*
-* Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     liuyanga <liuyanga@uniontech.com>
-*
-* Maintainer: liuyanga <liuyanga@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "middleviewdelegate.h"
 #include "middleview.h"
@@ -268,7 +252,7 @@ QWidget *MiddleViewDelegate::createEditor(QWidget *parent, const QStyleOptionVie
     Q_UNUSED(index)
     QLineEdit *editBox = new QLineEdit(parent);
     editBox->setMaxLength(MAX_TITLE_LEN);
-    editBox->setFixedSize(204, 38);
+    editBox->resize(parent->geometry().width() - 56, 38);
     editBox->installEventFilter(m_parentView);
     return editBox;
 }
@@ -327,6 +311,7 @@ void MiddleViewDelegate::updateEditorGeometry(QWidget *editor, const QStyleOptio
                                               const QModelIndex &index) const
 {
     QLineEdit *edit = static_cast<QLineEdit *>(editor);
+    edit->resize(m_parentView->geometry().width() - 56, 38);
     if (m_searchKey.isEmpty() && index.isValid() && index.row() == 0) {
         VNoteItem *data = static_cast<VNoteItem *>(StandardItemCommon::getStandardItemData(index));
         if (data && data->isTop) {
@@ -426,7 +411,7 @@ void MiddleViewDelegate::paintNormalItem(QPainter *painter, const QStyleOptionVi
 
     } else {
         itemBaseRect = QRect(option.rect.x() + 10, option.rect.y() + 5,
-                             option.rect.width() - 20, option.rect.height() - 10);
+                             qMin(m_parentView->geometry().width(), option.rect.width()) - 20, option.rect.height() - 10);
     }
 
     painter->save();
@@ -487,7 +472,7 @@ void MiddleViewDelegate::paintSearchItem(QPainter *painter, const QStyleOptionVi
         return;
     }
     QRect paintRect(option.rect.x() + 10, option.rect.y() + 5,
-                    option.rect.width() - 20, option.rect.height() - 10);
+                    qMin(m_parentView->geometry().width(), option.rect.width()) - 20, option.rect.height() - 10);
     bool isSelect = false;
     painter->save();
     painter->setRenderHint(QPainter::Antialiasing, true);
