@@ -1,23 +1,7 @@
-/*
-* Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     liuyanga <liuyanga@uniontech.com>
-*
-* Maintainer: liuyanga <liuyanga@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "views/vnotemainwindow.h"
 #include "views/leftview.h"
@@ -333,6 +317,26 @@ void VNoteMainWindow::initShortcuts()
     m_stPreviewShortcuts->setAutoRepeat(false);
     connect(m_stPreviewShortcuts.get(), &QShortcut::activated,
             this, &VNoteMainWindow::onPreviewShortcut);
+
+    m_stVoice2Text.reset(new QShortcut(this));
+    m_stVoice2Text->setKey(QString("Ctrl+W"));
+    m_stVoice2Text->setContext(Qt::ApplicationShortcut);
+    m_stVoice2Text->setAutoRepeat(false);
+    connect(m_stVoice2Text.get(), &QShortcut::activated, this, [ = ] {
+        qDebug() << __FUNCTION__ << __LINE__;
+        //emit JsContent::instance()->callJsVoiceToOther(0);
+        //m_richTextEdit->onMenuActionClicked(ActionManager::Instance()->getActionById(ActionManager::VoiceToText));
+    });
+
+    m_stVoice2Mp3.reset(new QShortcut(this));
+    m_stVoice2Mp3->setKey(QString("Ctrl+P"));
+    m_stVoice2Mp3->setContext(Qt::ApplicationShortcut);
+    m_stVoice2Mp3->setAutoRepeat(false);
+    connect(m_stVoice2Mp3.get(), &QShortcut::activated, this, [ = ] {
+        qDebug() << __FUNCTION__ << __LINE__;
+        //emit JsContent::instance()->callJsVoiceToOther(1);
+        //m_richTextEdit->onMenuActionClicked(ActionManager::Instance()->getActionById(ActionManager::VoiceAsSave));
+    });
 }
 
 /**
@@ -367,7 +371,8 @@ void VNoteMainWindow::initTitleBar()
     // Search note
     m_noteSearchEdit = new DSearchEdit(this);
     DFontSizeManager::instance()->bind(m_noteSearchEdit, DFontSizeManager::T6);
-    m_noteSearchEdit->setFixedSize(QSize(VNOTE_SEARCHBAR_W, VNOTE_SEARCHBAR_H));
+    m_noteSearchEdit->setMaximumSize(QSize(VNOTE_SEARCHBAR_W, VNOTE_SEARCHBAR_H));
+    m_noteSearchEdit->setMinimumSize(QSize(VNOTE_SEARCHBAR_MIN_W, VNOTE_SEARCHBAR_H));
     m_noteSearchEdit->setPlaceHolder(DApplication::translate("TitleBar", "Search"));
     m_noteSearchEdit->lineEdit()->installEventFilter(this);
 
@@ -443,7 +448,8 @@ void VNoteMainWindow::initLeftView()
     m_leftViewHolder = new QWidget(m_mainWndSpliter);
     m_leftViewHolder->setObjectName("leftMainLayoutHolder");
     m_leftViewHolder->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Expanding);
-    m_leftViewHolder->setFixedWidth(VNOTE_LEFTVIEW_W);
+    m_leftViewHolder->setMinimumWidth(VNOTE_LEFTVIEW_MIN_W);
+    m_leftViewHolder->setMaximumWidth(VNOTE_LEFTVIEW_W);
     m_leftViewHolder->setBackgroundRole(DPalette::Base);
     m_leftViewHolder->setAutoFillBackground(true);
 
@@ -486,7 +492,8 @@ void VNoteMainWindow::initMiddleView()
     m_middleViewHolder = new QWidget(m_mainWndSpliter);
     m_middleViewHolder->setObjectName("middleMainLayoutHolder");
     m_middleViewHolder->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Expanding);
-    m_middleViewHolder->setFixedWidth(VNOTE_MIDDLEVIEW_W);
+    m_middleViewHolder->setMaximumWidth(VNOTE_MIDDLEVIEW_W);
+    m_middleViewHolder->setMinimumWidth(VNOTE_MIDDLEVIEW_MIN_W);
     m_middleViewHolder->setBackgroundRole(DPalette::Base);
     m_middleViewHolder->setAutoFillBackground(true);
 
@@ -499,14 +506,15 @@ void VNoteMainWindow::initMiddleView()
     m_addNoteBtn->setFixedSize(QSize(54, 54));
     m_addNoteBtn->raise();
 
-    DAnchorsBase buttonAnchor(m_addNoteBtn);
-    buttonAnchor.setAnchor(Qt::AnchorLeft, m_middleView, Qt::AnchorLeft);
-    buttonAnchor.setAnchor(Qt::AnchorBottom, m_middleView, Qt::AnchorBottom);
-    buttonAnchor.setBottomMargin(6);
-    buttonAnchor.setLeftMargin(97);
+    m_buttonAnchor = new DAnchorsBase(m_addNoteBtn);
+    m_buttonAnchor->setAnchor(Qt::AnchorLeft, m_middleView, Qt::AnchorLeft);
+    m_buttonAnchor->setAnchor(Qt::AnchorBottom, m_middleView, Qt::AnchorBottom);
+    m_buttonAnchor->setBottomMargin(6);
+    m_buttonAnchor->setLeftMargin(97);
 
     m_middleView->installEventFilter(this);
     m_addNoteBtn->installEventFilter(this);
+    m_middleViewHolder->installEventFilter(this);
     // ToDo:
     //    Add Left view widget here
     middleHolderLayout->addWidget(m_middleView);
@@ -1051,6 +1059,19 @@ void VNoteMainWindow::closeEvent(QCloseEvent *event)
  */
 void VNoteMainWindow::resizeEvent(QResizeEvent *event)
 {
+
+    if(this->geometry().width() >= DEFAULT_WINDOWS_WIDTH) {
+        m_noteSearchEdit->resize(VNOTE_SEARCHBAR_W, VNOTE_SEARCHBAR_H);
+    } else if (this->geometry().width() <= MIN_WINDOWS_WIDTH) {
+        m_noteSearchEdit->resize(VNOTE_SEARCHBAR_MIN_W, VNOTE_SEARCHBAR_H);
+    } else {
+        double wMainWin = (this->geometry().width() * 1.0) / DEFAULT_WINDOWS_WIDTH;
+        int wsearch =VNOTE_SEARCHBAR_W * wMainWin;
+        m_noteSearchEdit->resize(wsearch , VNOTE_SEARCHBAR_H);
+    }
+
+    m_middleView->repaint();
+
     if (m_asrErrMeassage && m_asrErrMeassage->isVisible()) {
         int xPos = (m_centerWidget->width() - m_asrErrMeassage->width()) / 2;
         int yPos = m_centerWidget->height() - m_asrErrMeassage->height() - 5;
@@ -1996,6 +2017,13 @@ void VNoteMainWindow::setTitleBarTabFocus(QKeyEvent *event)
  */
 bool VNoteMainWindow::eventFilter(QObject *o, QEvent *e)
 {
+    if (o == m_middleViewHolder && e->type() == QEvent::Resize) {
+        // 更新按钮位置
+        int position = (m_middleViewHolder->width() - m_addNoteBtn->width()) / 2 - 6;
+        m_buttonAnchor->setLeftMargin(position);
+        m_middleView->resize(m_middleViewHolder->width(), m_middleViewHolder->height());
+        return true;
+    }
     if (e->type() == QEvent::KeyPress) {
         QKeyEvent *keyEvent = dynamic_cast<QKeyEvent *>(e);
         if (keyEvent->key() == Qt::Key_Tab) {
