@@ -1,21 +1,21 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl" version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
 <context>
     <name>AppMain</name>
     <message>
-        <location filename="../src/common/vlcpalyer.cpp" line="54"/>
-        <location filename="../src/main.cpp" line="76"/>
-        <location filename="../src/main.cpp" line="77"/>
-        <location filename="../src/views/vnotemainwindow.cpp" line="605"/>
+        <location filename="src/common/vlcpalyer.cpp" line="54"/>
+        <location filename="src/main.cpp" line="94"/>
+        <location filename="src/main.cpp" line="95"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="615"/>
         <source>Voice Notes</source>
         <translation>Memorecorder</translation>
     </message>
     <message>
-        <location filename="../src/main.cpp" line="78"/>
+        <location filename="src/main.cpp" line="96"/>
         <source>Voice Notes is a lightweight memo tool to make text notes and voice recordings.</source>
         <translation>Met Memorecorder kun je eenvoudig memo&apos;s opnemen en aantekeningen maken.</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="606"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="616"/>
         <source>Recordings not saved</source>
         <translation>Opnames niet opgeslagen</translation>
     </message>
@@ -23,18 +23,18 @@
 <context>
     <name>DefaultName</name>
     <message>
-        <location filename="../src/db/vnotefolderoper.cpp" line="245"/>
+        <location filename="src/db/vnotefolderoper.cpp" line="245"/>
         <source>Notebook</source>
         <translation>Notitieboek</translation>
     </message>
     <message>
-        <location filename="../src/db/vnoteitemoper.cpp" line="228"/>
+        <location filename="src/db/vnoteitemoper.cpp" line="228"/>
         <source>Text</source>
         <translation>Tekst</translation>
     </message>
     <message>
-        <location filename="../src/db/vnoteitemoper.cpp" line="243"/>
-        <location filename="../src/importolddata/olddbvisistors.cpp" line="154"/>
+        <location filename="src/db/vnoteitemoper.cpp" line="243"/>
+        <location filename="src/importolddata/olddbvisistors.cpp" line="154"/>
         <source>Voice</source>
         <translation>Memo</translation>
     </message>
@@ -42,7 +42,7 @@
 <context>
     <name>DetailPage</name>
     <message>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="213"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="213"/>
         <source>%1 notes selected</source>
         <translation>%1 aantekeningen geselecteerd</translation>
     </message>
@@ -50,18 +50,18 @@
 <context>
     <name>FolderSelectDialog</name>
     <message>
-        <location filename="../src/dialog/folderselectdialog.cpp" line="217"/>
+        <location filename="src/dialog/folderselectdialog.cpp" line="217"/>
         <source>Move Notes</source>
         <translation>Memo&apos;s verplaatsen</translation>
     </message>
     <message>
-        <location filename="../src/dialog/folderselectdialog.cpp" line="244"/>
+        <location filename="src/dialog/folderselectdialog.cpp" line="244"/>
         <source>Cancel</source>
         <comment>button</comment>
         <translation>Annuleren</translation>
     </message>
     <message>
-        <location filename="../src/dialog/folderselectdialog.cpp" line="245"/>
+        <location filename="src/dialog/folderselectdialog.cpp" line="245"/>
         <source>Confirm</source>
         <comment>button</comment>
         <translation>Ja</translation>
@@ -70,12 +70,12 @@
 <context>
     <name>HomePage</name>
     <message>
-        <location filename="../src/views/homepage.cpp" line="48"/>
+        <location filename="src/views/homepage.cpp" line="48"/>
         <source>Create Notebook</source>
         <translation>Notitieboek maken</translation>
     </message>
     <message>
-        <location filename="../src/views/homepage.cpp" line="60"/>
+        <location filename="src/views/homepage.cpp" line="60"/>
         <source>Create a notebook to start recording voice and making notes</source>
         <translation>Maak een notitieboek om memo&apos;s op te nemen en aantekeningen te maken</translation>
     </message>
@@ -83,28 +83,28 @@
 <context>
     <name>LeftView</name>
     <message>
-        <location filename="../src/dialog/folderselectdialog.cpp" line="381"/>
-        <location filename="../src/dialog/folderselectdialog.cpp" line="384"/>
-        <location filename="../src/dialog/folderselectdialog.cpp" line="392"/>
-        <source>Move the note &quot;%1&quot; to:</source>
-        <translation>‘%1’ verplaatsen naar:</translation>
-    </message>
-    <message>
-        <location filename="../src/dialog/folderselectdialog.cpp" line="380"/>
-        <location filename="../src/dialog/folderselectdialog.cpp" line="394"/>
+        <location filename="src/dialog/folderselectdialog.cpp" line="380"/>
+        <location filename="src/dialog/folderselectdialog.cpp" line="394"/>
         <source>Move %1 notes (%2, ...) to:</source>
         <translation>%1 memo&apos;s (%2, …) verplaatsen naar:</translation>
     </message>
+    <message>
+        <location filename="src/dialog/folderselectdialog.cpp" line="381"/>
+        <location filename="src/dialog/folderselectdialog.cpp" line="384"/>
+        <location filename="src/dialog/folderselectdialog.cpp" line="392"/>
+        <source>Move the note &quot;%1&quot; to:</source>
+        <translation>‘%1’ verplaatsen naar:</translation>
+    </message>
 </context>
 <context>
     <name>MiddleView</name>
     <message>
-        <location filename="../src/views/middleview.cpp" line="276"/>
+        <location filename="src/views/middleview.cpp" line="303"/>
         <source>Save</source>
         <translation>Opslaan</translation>
     </message>
     <message>
-        <location filename="../src/views/middleview.cpp" line="1070"/>
+        <location filename="src/views/middleview.cpp" line="1057"/>
         <source>No search results</source>
         <translation>Geen zoekresultaten</translation>
     </message>
@@ -112,7 +112,7 @@
 <context>
     <name>MiddleViewDelegate</name>
     <message>
-        <location filename="../src/views/middleviewdelegate.cpp" line="442"/>
+        <location filename="src/views/middleviewdelegate.cpp" line="442"/>
         <source>Sticky Notes</source>
         <translation>Vastgezette memo&apos;s</translation>
     </message>
@@ -120,77 +120,77 @@
 <context>
     <name>NoteDetailContextMenu</name>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="282"/>
+        <location filename="src/common/actionmanager.cpp" line="276"/>
         <source>Save as MP3</source>
         <translation>Opslaan als mp3-bestand</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="283"/>
+        <location filename="src/common/actionmanager.cpp" line="277"/>
         <source>Voice to Text</source>
         <translation>Spraak-naar-tekst</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="284"/>
-        <location filename="../src/common/actionmanager.cpp" line="311"/>
-        <location filename="../src/common/actionmanager.cpp" line="337"/>
+        <location filename="src/common/actionmanager.cpp" line="278"/>
+        <location filename="src/common/actionmanager.cpp" line="305"/>
+        <location filename="src/common/actionmanager.cpp" line="331"/>
         <source>Delete</source>
         <translation>Verwijderen</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="285"/>
-        <location filename="../src/common/actionmanager.cpp" line="312"/>
-        <location filename="../src/common/actionmanager.cpp" line="338"/>
+        <location filename="src/common/actionmanager.cpp" line="279"/>
+        <location filename="src/common/actionmanager.cpp" line="306"/>
+        <location filename="src/common/actionmanager.cpp" line="332"/>
         <source>Select all</source>
         <translation>Alles selecteren</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="286"/>
-        <location filename="../src/common/actionmanager.cpp" line="313"/>
-        <location filename="../src/common/actionmanager.cpp" line="339"/>
+        <location filename="src/common/actionmanager.cpp" line="280"/>
+        <location filename="src/common/actionmanager.cpp" line="307"/>
+        <location filename="src/common/actionmanager.cpp" line="333"/>
         <source>Copy</source>
         <translation>Kopiëren</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="287"/>
-        <location filename="../src/common/actionmanager.cpp" line="314"/>
-        <location filename="../src/common/actionmanager.cpp" line="340"/>
+        <location filename="src/common/actionmanager.cpp" line="281"/>
+        <location filename="src/common/actionmanager.cpp" line="308"/>
+        <location filename="src/common/actionmanager.cpp" line="334"/>
         <source>Cut</source>
         <translation>Knippen</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="288"/>
-        <location filename="../src/common/actionmanager.cpp" line="315"/>
-        <location filename="../src/common/actionmanager.cpp" line="341"/>
+        <location filename="src/common/actionmanager.cpp" line="282"/>
+        <location filename="src/common/actionmanager.cpp" line="309"/>
+        <location filename="src/common/actionmanager.cpp" line="335"/>
         <source>Paste</source>
         <translation>Plakken</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="310"/>
+        <location filename="src/common/actionmanager.cpp" line="304"/>
         <source>View</source>
         <translation>Bekijken</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="316"/>
+        <location filename="src/common/actionmanager.cpp" line="310"/>
         <source>Save as</source>
         <translation>Opslaan als</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="342"/>
+        <location filename="src/common/actionmanager.cpp" line="336"/>
         <source>Text to Speech</source>
         <translation>Tekst-naar-spraak</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="343"/>
+        <location filename="src/common/actionmanager.cpp" line="337"/>
         <source>Stop reading</source>
         <translation>Stoppen met voorlezen</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="344"/>
+        <location filename="src/common/actionmanager.cpp" line="338"/>
         <source>Speech to Text</source>
         <translation>Spraak-naar-tekst</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="345"/>
+        <location filename="src/common/actionmanager.cpp" line="339"/>
         <source>Translate</source>
         <translation>Vertalen</translation>
     </message>
@@ -198,17 +198,17 @@
 <context>
     <name>NotebookContextMenu</name>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="226"/>
+        <location filename="src/common/actionmanager.cpp" line="220"/>
         <source>Rename</source>
         <translation>Naam wijzigen</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="227"/>
+        <location filename="src/common/actionmanager.cpp" line="221"/>
         <source>Delete</source>
         <translation>Verwijderen</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="228"/>
+        <location filename="src/common/actionmanager.cpp" line="222"/>
         <source>New note</source>
         <translation>Nieuwe memo</translation>
     </message>
@@ -216,64 +216,64 @@
 <context>
     <name>NotesContextMenu</name>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="246"/>
-        <source>Rename</source>
-        <translation>Naam wijzigen</translation>
-    </message>
-    <message>
-        <location filename="../src/common/actionmanager.cpp" line="248"/>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="336"/>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="345"/>
-        <source>Move</source>
-        <translation>Verplaatsen</translation>
-    </message>
-    <message>
-        <location filename="../src/common/actionmanager.cpp" line="249"/>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="338"/>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="344"/>
-        <source>Delete</source>
-        <translation>Verwijderen</translation>
-    </message>
-    <message>
-        <location filename="../src/common/actionmanager.cpp" line="201"/>
-        <source>Save as TXT</source>
-        <translation>Opslaan als tekstbestand</translation>
-    </message>
-    <message>
-        <location filename="../src/common/actionmanager.cpp" line="200"/>
+        <location filename="src/common/actionmanager.cpp" line="195"/>
         <source>Save as HTML</source>
         <translation>Opslaan als html-bestand</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="205"/>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="342"/>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="353"/>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="359"/>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="361"/>
+        <location filename="src/common/actionmanager.cpp" line="196"/>
+        <source>Save as TXT</source>
+        <translation>Opslaan als tekstbestand</translation>
+    </message>
+    <message>
+        <location filename="src/common/actionmanager.cpp" line="200"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="342"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="353"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="359"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="361"/>
         <source>Save note</source>
         <translation>Memo opslaan</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="251"/>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="343"/>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="354"/>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="366"/>
-        <location filename="../src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="368"/>
+        <location filename="src/common/actionmanager.cpp" line="240"/>
+        <source>Rename</source>
+        <translation>Naam wijzigen</translation>
+    </message>
+    <message>
+        <location filename="src/common/actionmanager.cpp" line="242"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="336"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="345"/>
+        <source>Move</source>
+        <translation>Verplaatsen</translation>
+    </message>
+    <message>
+        <location filename="src/common/actionmanager.cpp" line="243"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="338"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="344"/>
+        <source>Delete</source>
+        <translation>Verwijderen</translation>
+    </message>
+    <message>
+        <location filename="src/common/actionmanager.cpp" line="245"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="343"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="354"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="366"/>
+        <location filename="src/widgets/vnotemultiplechoiceoptionwidget.cpp" line="368"/>
         <source>Save voice recording</source>
         <translation>Memo opslaan</translation>
     </message>
     <message>
-        <location filename="../src/common/actionmanager.cpp" line="252"/>
+        <location filename="src/common/actionmanager.cpp" line="246"/>
         <source>New note</source>
         <translation>Nieuwe memo</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="1240"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="1258"/>
         <source>Unstick</source>
         <translation>Losmaken</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="1242"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="1260"/>
         <source>Sticky on Top</source>
         <translation>Vastzetten aan bovenkant</translation>
     </message>
@@ -281,22 +281,22 @@
 <context>
     <name>Setting</name>
     <message>
-        <location filename="../src/common/setting.cpp" line="41"/>
+        <location filename="src/common/setting.cpp" line="39"/>
         <source>Basic</source>
         <translation>Algemeen</translation>
     </message>
     <message>
-        <location filename="../src/common/setting.cpp" line="42"/>
+        <location filename="src/common/setting.cpp" line="40"/>
         <source>Audio Source</source>
         <translation>Audiobron</translation>
     </message>
     <message>
-        <location filename="../src/common/setting.cpp" line="43"/>
+        <location filename="src/common/setting.cpp" line="41"/>
         <source>Internal</source>
         <translation>Intern</translation>
     </message>
     <message>
-        <location filename="../src/common/setting.cpp" line="44"/>
+        <location filename="src/common/setting.cpp" line="42"/>
         <source>Microphone</source>
         <translation>Microfoon</translation>
     </message>
@@ -304,87 +304,87 @@
 <context>
     <name>Shortcuts</name>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="902"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="919"/>
         <source>New notebook</source>
         <translation>Notitieboek maken</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="903"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="920"/>
         <source>Rename notebook</source>
         <translation>Naam wijzigen</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="904"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="921"/>
         <source>Delete notebook</source>
         <translation>Notitieboek verwijderen</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="926"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="943"/>
         <source>New note</source>
         <translation>Nieuwe memo</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="927"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="944"/>
         <source>Rename note</source>
         <translation>Memonaam wijzigen</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="928"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="945"/>
         <source>Delete note</source>
         <translation>Memo verwijderen</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="929"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="946"/>
         <source>Play/Pause</source>
         <translation>Afspelen/Pauzeren</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="930"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="947"/>
         <source>Record voice</source>
         <translation>Memo maken</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="931"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="948"/>
         <source>Save note</source>
         <translation>Memo opslaan</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="932"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="949"/>
         <source>Save recordings</source>
         <translation>Memo&apos;s opslaan</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="952"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="969"/>
         <source>Select all</source>
         <translation>Alles selecteren</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="953"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="970"/>
         <source>Copy</source>
         <translation>Kopiëren</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="954"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="971"/>
         <source>Cut</source>
         <translation>Knippen</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="955"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="972"/>
         <source>Paste</source>
         <translation>Plakken</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="956"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="973"/>
         <source>Delete</source>
         <translation>Verwijderen</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="979"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="996"/>
         <source>Help</source>
         <translation>Hulp</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="980"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="997"/>
         <source>Display shortcuts</source>
         <translation>Sneltoetsen tonen</translation>
     </message>
@@ -392,22 +392,22 @@
 <context>
     <name>ShortcutsGroups</name>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="908"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="925"/>
         <source>Notebooks</source>
         <translation>Notitieboeken</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="936"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="953"/>
         <source>Notes</source>
         <translation>Memo&apos;s</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="960"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="977"/>
         <source>Edit</source>
         <translation>Bewerken</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="984"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="1001"/>
         <source>Settings</source>
         <translation>Instellingen</translation>
     </message>
@@ -415,7 +415,7 @@
 <context>
     <name>SplashView</name>
     <message>
-        <location filename="../src/views/splashview.cpp" line="46"/>
+        <location filename="src/views/splashview.cpp" line="46"/>
         <source>Loading...</source>
         <translation>Bezig met laden…</translation>
     </message>
@@ -423,17 +423,17 @@
 <context>
     <name>TitleBar</name>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="374"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="371"/>
         <source>Search</source>
         <translation>Zoeken</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="1869"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="1889"/>
         <source>Settings</source>
         <translation>Instellingen</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="1870"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="1890"/>
         <source>Privacy Policy</source>
         <translation>Privacybeleid</translation>
     </message>
@@ -441,7 +441,7 @@
 <context>
     <name>UpgradeView</name>
     <message>
-        <location filename="../src/importolddata/upgradeview.cpp" line="50"/>
+        <location filename="src/importolddata/upgradeview.cpp" line="50"/>
         <source>Importing notes from the old version, please wait...</source>
         <translation>Bezig met importeren van aantekeningen uit oude versie…</translation>
     </message>
@@ -449,19 +449,17 @@
 <context>
     <name>Utils</name>
     <message>
-        <location filename="../src/common/utils.cpp" line="56"/>
-        <location filename="../tests/src/common/ut_utils.cpp" line="45"/>
-        <location filename="../tests/src/common/ut_utils.cpp" line="46"/>
+        <location filename="src/common/utils.cpp" line="56"/>
         <source>1 min ago</source>
         <translation>1 min geleden</translation>
     </message>
     <message>
-        <location filename="../src/common/utils.cpp" line="58"/>
+        <location filename="src/common/utils.cpp" line="58"/>
         <source>%1 mins ago</source>
         <translation>%1 min geleden</translation>
     </message>
     <message>
-        <location filename="../src/common/utils.cpp" line="64"/>
+        <location filename="src/common/utils.cpp" line="64"/>
         <source>Yesterday</source>
         <translation>Gisteren</translation>
     </message>
@@ -469,12 +467,12 @@
 <context>
     <name>VNoteErrorMessage</name>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="864"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="881"/>
         <source>The voice conversion failed due to the poor network connection, please have a check</source>
         <translation>Het omzetten is mislukt omdat je internetverbinding zwak is. Wil je het opnieuw proberen?</translation>
     </message>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="868"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="885"/>
         <source>Voice to text conversion failed</source>
         <translation>Omzetten mislukt</translation>
     </message>
@@ -482,7 +480,7 @@
 <context>
     <name>VNoteMainWindow</name>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="467"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="470"/>
         <source>Create Notebook</source>
         <translation>Notitieboek maken</translation>
     </message>
@@ -490,88 +488,77 @@
 <context>
     <name>VNoteMessageDialog</name>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="53"/>
-        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="35"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="53"/>
         <source>OK</source>
         <comment>button</comment>
         <translation>Oké</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="132"/>
-        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="101"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="132"/>
         <source>Cancel</source>
         <comment>button</comment>
         <translation>Annuleren</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="133"/>
-        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="105"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="133"/>
         <source>Confirm</source>
         <comment>button</comment>
         <translation>Ja</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="136"/>
-        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="46"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="136"/>
         <source>Are you sure you want to delete this notebook?
 All notes in it will be deleted</source>
         <translation>Weet je zeker dat je dit notitieboek wilt verwijderen?
 Alle bijbehorende memo&apos;s worden eveneens verwijderd.</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="139"/>
-        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="53"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="139"/>
         <source>Do you want to stop the current recording?</source>
         <translation>Wil je de huidige opname afbreken?</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="143"/>
-        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="94"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="143"/>
         <source>Are you sure you want to delete the selected %1 notes?</source>
         <translation>Weet je zeker dat je de %1 geselecteerde aantekeningen wilt verwijderen?</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="145"/>
-        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="88"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="145"/>
         <source>Are you sure you want to delete this note?</source>
         <translation>Weet je zeker dat je deze memo wilt verwijderen?</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="149"/>
-        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="59"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="149"/>
         <source>Cannot convert this voice note, as notes over 20 minutes are not supported at present.</source>
         <translation>Deze memo kan niet worden omgezet omdat memo&apos;s van 20 minuten of langer momenteel niet worden ondersteund.</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="153"/>
-        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="66"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="153"/>
         <source>Converting a voice note now. Do you want to stop it?</source>
         <translation>De memo wordt momenteel omgezet. Wil je dit proces afbreken?</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="156"/>
-        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="72"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="156"/>
         <source>The low input volume may result in bad recordings. Do you want to continue?</source>
         <translation>Het invoervolume is laag, wat kan leiden tot slechte opnames. Weet je zeker dat je wilt doorgaan?</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="159"/>
-        <location filename="../tests/src/dialog/ut_vnotemessagedialog.cpp" line="79"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="159"/>
         <source>The clipped recordings and converted text will not be pasted. Do you want to continue?</source>
         <translation>De geknipte memo&apos;s en omgezette tekst worden niet geplakt. Weet je zeker dat je wilt doorgaan?</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="162"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="162"/>
         <source>Save failed</source>
         <translation>Opslaan mislukt</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="166"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="166"/>
         <source>You do not have permission to save files there</source>
         <translation>Je bent niet bevoegd om hier bestanden op te slaan</translation>
     </message>
     <message>
-        <location filename="../src/dialog/vnotemessagedialog.cpp" line="170"/>
+        <location filename="src/dialog/vnotemessagedialog.cpp" line="170"/>
         <source>The voice note has been deleted</source>
         <translation>De memo is verwijderd</translation>
     </message>
@@ -579,12 +566,12 @@ Alle bijbehorende memo&apos;s worden eveneens verwijderd.</translation>
 <context>
     <name>VNoteRecordBar</name>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="1714"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="1736"/>
         <source>Your audio recording device does not work.</source>
         <translation>Je opnameapparaat werkt niet.</translation>
     </message>
     <message>
-        <location filename="../src/views/vnoterecordbar.cpp" line="249"/>
+        <location filename="src/views/vnoterecordbar.cpp" line="249"/>
         <source>No recording device detected</source>
         <translation>Geen opnameapparaat aangetroffen</translation>
     </message>
@@ -592,7 +579,7 @@ Alle bijbehorende memo&apos;s worden eveneens verwijderd.</translation>
 <context>
     <name>VoiceNoteItem</name>
     <message>
-        <location filename="../src/views/vnotemainwindow.cpp" line="1657"/>
+        <location filename="src/views/vnotemainwindow.cpp" line="1679"/>
         <source>Converting voice to text</source>
         <translation>Bezig met omzetten…</translation>
     </message>
@@ -600,57 +587,62 @@ Alle bijbehorende memo&apos;s worden eveneens verwijderd.</translation>
 <context>
     <name>web</name>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="138"/>
+        <location filename="src/common/jscontent.cpp" line="141"/>
+        <source>Font</source>
+        <translation>Lettertype</translation>
+    </message>
+    <message>
+        <location filename="src/common/jscontent.cpp" line="142"/>
         <source>Font size</source>
         <translation>Tekstgrootte</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="139"/>
+        <location filename="src/common/jscontent.cpp" line="143"/>
         <source>Font color</source>
         <translation>Tekstkleur</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="140"/>
+        <location filename="src/common/jscontent.cpp" line="144"/>
         <source>Text highlight color</source>
         <translation>Markeerkleur</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="141"/>
+        <location filename="src/common/jscontent.cpp" line="145"/>
         <source>Bold</source>
         <translation>Vetgedrukt</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="142"/>
+        <location filename="src/common/jscontent.cpp" line="146"/>
         <source>Italic</source>
         <translation>Cunsief</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="143"/>
+        <location filename="src/common/jscontent.cpp" line="147"/>
         <source>Underline</source>
         <translation>Onderstrepen</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="144"/>
+        <location filename="src/common/jscontent.cpp" line="148"/>
         <source>Strikethrough</source>
         <translation>Doorhalen</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="145"/>
+        <location filename="src/common/jscontent.cpp" line="149"/>
         <source>Bullets</source>
         <translation>Ongenummerde lijst</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="146"/>
+        <location filename="src/common/jscontent.cpp" line="150"/>
         <source>Numbering</source>
         <translation>Genummerde lijst</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="147"/>
+        <location filename="src/common/jscontent.cpp" line="151"/>
         <source>More colors</source>
         <translation>Meer kleuren</translation>
     </message>
     <message>
-        <location filename="../src/common/jscontent.cpp" line="148"/>
+        <location filename="src/common/jscontent.cpp" line="152"/>
         <source>Recent</source>
         <translation>Recent</translation>
     </message>
